from collections import OrderedDict

from mintamazontagger import amazon
from mintamazontagger import mint


def transaction(*args, **kwargs):
    return mint.Transaction(transaction_json(*args, **kwargs))


def order(*args, **kwargs):
    return amazon.Order(order_dict(*args, **kwargs))


def item(*args, **kwargs):
    return amazon.Item(item_dict(*args, **kwargs))


def refund(*args, **kwargs):
    return amazon.Refund(refund_dict(*args, **kwargs))


def transaction_json(
        amount=-11.95,
        category='Personal Care',
        date='2014-02-28',
        description='Amazon',
        original_description='AMAZON MKTPLACE PMTS',
        id=975256256,
        parent_id=None,
        notes='Great note here'):
    return {
        'accountId': '18888881_9382019',
        'accountRef': {
            'hiddenFromPlanningAndTrends': False,
            'id': '9382019',
            'name': 'Amazon',
            'type': 'CreditAccount'},
        'amount': amount,
        'category': {
            'categoryType': 'EXPENSE',
            'id': '18888881_2',
            'name': category,
            'parentId': '18888881_0',
            'parentName': 'Root'},
        'date': date,
        'description': description,
        'discretionaryType': 'DISCRETIONARY',
        'etag': '1655502962000',
        'fiData': {
            'amount': amount,
            'date': date,
            'description': original_description,
            'id': '202205251030281220511#20220511',
            'inferredCategory': {
                'id': '18888881_2',
                'name': 'Shopping'},
            'inferredDescription': 'AMZN Mktp US*TW7KN5RV3'},
        'id': id,
        'isExpense': True,
        'isLinkedToRule': False,
        'isPending': False,
        'isReviewed': False,
        'matchState': 'NOT_MATCHED',
        'merchantId': 7218,
        'metaData': {
            'lastUpdatedDate': '2022-06-17T21:56:02Z',
            'link': [{
                'href': '/v1/transactions/18888881_2253990866_0',
                'otherAttributes': {},
                'rel': 'self'}]},
        'notes': notes,
        'parentId': parent_id,
        'status': 'POSTED',
        'transactionReviewState': 'UNREVIEWED',
        'type': 'CashAndCreditTransaction'}


def category_json(name='Personal Care', id=4):
    return {
        'id': id,
        'name': name,
    }


def order_dict(
        subtotal='$10.90',
        shipping_charge='$0.00',
        tax_charged='$1.05',
        total_charged='$11.95',
        tax_before_promotions='$1.05',
        total_promotions='$0.00',
        tracking='AMZN(ABC123)',
        order_status='Shipped',
        order_id='123-3211232-7655671',
        order_date='02/26/14',
        shipment_date='02/28/14',
        payment_type='Great Credit Card'):
    return OrderedDict([
        ('Order Date', order_date),
        ('Order ID', order_id),
        ('Payment Instrument Type', payment_type),
        ('Website', 'Amazon.com'),
        ('Purchase Order Number', ''),
        ('Ordering Customer Email', 'yup@aol.com'),
        ('Shipment Date', shipment_date),
        ('Shipping Address Name', 'Some Great Buyer'),
        ('Shipping Address Street 1', 'The best city'),
        ('Shipping Address Street 2', 'But can be rainy, sometimes'),
        ('Shipping Address City', 'SEATTLE'),
        ('Shipping Address State', 'WA'),
        ('Shipping Address Zip', '98101-1001'),
        ('Order Status', order_status),
        ('Carrier Name & Tracking Number', tracking),
        ('Subtotal', subtotal),
        ('Shipping Charge', shipping_charge),
        ('Tax Before Promotions', tax_before_promotions),
        ('Total Promotions', total_promotions),
        ('Tax Charged', tax_charged),
        ('Total Charged', total_charged),
        ('Buyer Name', 'Some Great Buyer'),
        ('Group Name', 'Optional Group'),
    ])


def item_dict(
        title='Duracell AAs',
        item_subtotal='$10.90',
        item_subtotal_tax='$1.05',
        item_total='$11.95',
        purchase_price_per_unit='$5.45',
        tracking='AMZN(ABC123)',
        quantity=2,
        order_status='Shipped',
        order_id='123-3211232-7655671',
        order_date='02/26/14',
        shipment_date='02/28/14',
        payment_type='Great Credit Card'):
    return OrderedDict([
        ('Order Date', order_date),
        ('Order ID', order_id),
        ('Title', title),
        ('Category', 'Misc.'),
        ('ASIN/ISBN', 'B00009V2QX'),
        ('UNSPSC Code', '26111700'),
        ('Website', 'Amazon.com'),
        ('Release Date', '04/15/10'),
        ('Condition', 'new'),
        ('Seller', 'Todays Concept'),
        ('Seller Credentials', ''),
        ('List Price Per Unit', purchase_price_per_unit),
        ('Purchase Price Per Unit', purchase_price_per_unit),
        ('Quantity', str(quantity)),
        ('Payment Instrument Type', payment_type),
        ('Purchase Order Number', ''),
        ('PO Line Number', ''),
        ('Ordering Customer Email', 'yup@aol.com'),
        ('Shipment Date', shipment_date),
        ('Shipping Address Name', 'Some Great Buyer'),
        ('Shipping Address Street 1', 'The best city'),
        ('Shipping Address Street 2', 'But can be rainy, sometimes'),
        ('Shipping Address City', 'SEATTLE'),
        ('Shipping Address State', 'WA'),
        ('Shipping Address Zip', '98101-1001'),
        ('Order Status', order_status),
        ('Carrier Name & Tracking Number', tracking),
        ('Item Subtotal', item_subtotal),
        ('Item Subtotal Tax', item_subtotal_tax),
        ('Item Total', item_total),
        ('Tax Exemption Applied', ''),
        ('Tax Exemption Type', ''),
        ('Exemption Opt-Out', ''),
        ('Buyer Name', 'Some Great Buyer'),
        ('Currency', 'USD'),
        ('Group Name', 'Optional Group'),
    ])


def refund_dict(
        title='Duracell Procell AA 24 Pack PC1500BKD09',
        refund_amount='$10.90',
        refund_tax_amount='$1.05',
        tracking='AMZN(ABC123)',
        status='Shipped',
        quantity=2,
        order_id='123-3211232-7655671',
        order_date='02/26/14',
        refund_date='03/16/14'):
    return OrderedDict([
        ('Order Date', order_date),
        ('Order ID', order_id),
        ('Title', title),
        ('Category', 'Apparel'),
        ('ASIN/ISBN', 'B0174V9GZW'),
        ('Website', 'Amazon.com'),
        ('Purchase Order Number', ''),
        ('Refund Date', refund_date),
        ('Refund Condition', 'Completed'),
        ('Refund Amount', refund_amount),
        ('Refund Tax Amount', refund_tax_amount),
        ('Tax Exemption Applied', ''),
        ('Refund Reason', 'Customer Return'),
        ('Quantity', quantity),
        ('Seller', 'Customonaco'),
        ('Seller Credentials', ''),
        ('Buyer Name', 'Some Great Buyer'),
        ('Group Name', 'Optional Group'),
    ])


# Pulled mid 2022.
MINT_CATEGORIES = {
 'ATM Fee': {'categoryType': 'EXPENSE',
             'depth': 2,
             'discretionaryType': 'NON_DISCRETIONARY',
             'id': '18888881_1605',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': False,
             'isUnbudgetable': False,
             'isUntrendable': False,
             'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                          'link': [{'href': '/v1/categories/18888881_1605',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'ATM Fee',
             'parentId': '18888881_16',
             'type': 'Category'},
 'Advertising': {'categoryType': 'EXPENSE',
                 'depth': 2,
                 'discretionaryType': 'DISCRETIONARY',
                 'id': '18888881_1701',
                 'isBusiness': False,
                 'isCustom': False,
                 'isDeleted': False,
                 'isEditable': False,
                 'isIgnored': False,
                 'isUnassignable': False,
                 'isUnbudgetable': False,
                 'isUntrendable': False,
                 'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                              'link': [{'href': '/v1/categories/18888881_1701',
                                        'otherAttributes': {},
                                        'rel': 'self'}]},
                 'name': 'Advertising',
                 'parentId': '18888881_17',
                 'type': 'Category'},
 'Air Travel': {'categoryType': 'EXPENSE',
                'depth': 2,
                'discretionaryType': 'DISCRETIONARY',
                'id': '18888881_1501',
                'isBusiness': False,
                'isCustom': False,
                'isDeleted': False,
                'isEditable': False,
                'isIgnored': False,
                'isUnassignable': False,
                'isUnbudgetable': False,
                'isUntrendable': False,
                'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                             'link': [{'href': '/v1/categories/18888881_1501',
                                       'otherAttributes': {},
                                       'rel': 'self'}]},
                'name': 'Air Travel',
                'parentId': '18888881_15',
                'type': 'Category'},
 'Alcohol & Bars': {'categoryType': 'EXPENSE',
                    'depth': 2,
                    'discretionaryType': 'DISCRETIONARY',
                    'id': '18888881_708',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': False,
                    'isUnbudgetable': False,
                    'isUntrendable': False,
                    'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                 'link': [{'href': '/v1/categories/18888881_708',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Alcohol & Bars',
                    'parentId': '18888881_7',
                    'type': 'Category'},
 'Allowance': {'categoryType': 'EXPENSE',
               'depth': 2,
               'discretionaryType': 'DISCRETIONARY',
               'id': '18888881_610',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                            'link': [{'href': '/v1/categories/18888881_610',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Allowance',
               'parentId': '18888881_6',
               'type': 'Category'},
 'Amusement': {'categoryType': 'EXPENSE',
               'depth': 2,
               'discretionaryType': 'DISCRETIONARY',
               'id': '18888881_102',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                            'link': [{'href': '/v1/categories/18888881_102',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Amusement',
               'parentId': '18888881_1',
               'type': 'Category'},
 'Arts': {'categoryType': 'EXPENSE',
          'depth': 2,
          'discretionaryType': 'DISCRETIONARY',
          'id': '18888881_101',
          'isBusiness': False,
          'isCustom': False,
          'isDeleted': False,
          'isEditable': False,
          'isIgnored': False,
          'isUnassignable': False,
          'isUnbudgetable': False,
          'isUntrendable': False,
          'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                       'link': [{'href': '/v1/categories/18888881_101',
                                 'otherAttributes': {},
                                 'rel': 'self'}]},
          'name': 'Arts',
          'parentId': '18888881_1',
          'type': 'Category'},
 'Auto & Transport': {'categoryType': 'EXPENSE',
                      'depth': 1,
                      'discretionaryType': 'NON_DISCRETIONARY',
                      'id': '18888881_14',
                      'isBusiness': False,
                      'isCustom': False,
                      'isDeleted': False,
                      'isEditable': False,
                      'isIgnored': False,
                      'isUnassignable': False,
                      'isUnbudgetable': False,
                      'isUntrendable': False,
                      'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                   'link': [{'href': '/v1/categories/18888881_14',
                                             'otherAttributes': {},
                                             'rel': 'self'}]},
                      'name': 'Auto & Transport',
                      'type': 'Category'},
 'Auto Insurance': {'categoryType': 'EXPENSE',
                    'depth': 2,
                    'discretionaryType': 'NON_DISCRETIONARY',
                    'id': '18888881_1405',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': False,
                    'isUnbudgetable': False,
                    'isUntrendable': False,
                    'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                 'link': [{'href': '/v1/categories/18888881_1405',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Auto Insurance',
                    'parentId': '18888881_14',
                    'type': 'Category'},
 'Auto Payment': {'categoryType': 'EXPENSE',
                  'depth': 2,
                  'discretionaryType': 'NON_DISCRETIONARY',
                  'id': '18888881_1404',
                  'isBusiness': False,
                  'isCustom': False,
                  'isDeleted': False,
                  'isEditable': False,
                  'isIgnored': False,
                  'isUnassignable': False,
                  'isUnbudgetable': False,
                  'isUntrendable': False,
                  'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                               'link': [{'href': '/v1/categories/18888881_1404',
                                         'otherAttributes': {},
                                         'rel': 'self'}]},
                  'name': 'Auto Payment',
                  'parentId': '18888881_14',
                  'type': 'Category'},
 'Baby Supplies': {'categoryType': 'EXPENSE',
                   'depth': 2,
                   'discretionaryType': 'NON_DISCRETIONARY',
                   'id': '18888881_611',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                'link': [{'href': '/v1/categories/18888881_611',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Baby Supplies',
                   'parentId': '18888881_6',
                   'type': 'Category'},
 'Babysitter & Daycare': {'categoryType': 'EXPENSE',
                          'depth': 2,
                          'discretionaryType': 'NON_DISCRETIONARY',
                          'id': '18888881_602',
                          'isBusiness': False,
                          'isCustom': False,
                          'isDeleted': False,
                          'isEditable': False,
                          'isIgnored': False,
                          'isUnassignable': False,
                          'isUnbudgetable': False,
                          'isUntrendable': False,
                          'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                       'link': [{'href': '/v1/categories/18888881_602',
                                                 'otherAttributes': {},
                                                 'rel': 'self'}]},
                          'name': 'Babysitter & Daycare',
                          'parentId': '18888881_6',
                          'type': 'Category'},
 'Bank Fee': {'categoryType': 'EXPENSE',
              'depth': 2,
              'discretionaryType': 'NON_DISCRETIONARY',
              'id': '18888881_1606',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                           'link': [{'href': '/v1/categories/18888881_1606',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Bank Fee',
              'parentId': '18888881_16',
              'type': 'Category'},
 'Bills & Utilities': {'categoryType': 'EXPENSE',
                       'depth': 1,
                       'discretionaryType': 'NON_DISCRETIONARY',
                       'id': '18888881_13',
                       'isBusiness': False,
                       'isCustom': False,
                       'isDeleted': False,
                       'isEditable': False,
                       'isIgnored': False,
                       'isUnassignable': False,
                       'isUnbudgetable': False,
                       'isUntrendable': False,
                       'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                    'link': [{'href': '/v1/categories/18888881_13',
                                              'otherAttributes': {},
                                              'rel': 'self'}]},
                       'name': 'Bills & Utilities',
                       'type': 'Category'},
 'Bonus': {'categoryType': 'INCOME',
           'depth': 2,
           'discretionaryType': 'NONE',
           'id': '18888881_3004',
           'isBusiness': False,
           'isCustom': False,
           'isDeleted': False,
           'isEditable': False,
           'isIgnored': False,
           'isUnassignable': False,
           'isUnbudgetable': False,
           'isUntrendable': False,
           'metaData': {'lastUpdatedDate': '2013-07-12T05:39:16Z',
                        'link': [{'href': '/v1/categories/18888881_3004',
                                  'otherAttributes': {},
                                  'rel': 'self'}]},
           'name': 'Bonus',
           'parentId': '18888881_30',
           'type': 'Category'},
 'Books': {'categoryType': 'EXPENSE',
           'depth': 2,
           'discretionaryType': 'DISCRETIONARY',
           'id': '18888881_202',
           'isBusiness': False,
           'isCustom': False,
           'isDeleted': False,
           'isEditable': False,
           'isIgnored': False,
           'isUnassignable': False,
           'isUnbudgetable': False,
           'isUntrendable': False,
           'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                        'link': [{'href': '/v1/categories/18888881_202',
                                  'otherAttributes': {},
                                  'rel': 'self'}]},
           'name': 'Books',
           'parentId': '18888881_2',
           'type': 'Category'},
 'Books & Supplies': {'categoryType': 'EXPENSE',
                      'depth': 2,
                      'discretionaryType': 'DISCRETIONARY',
                      'id': '18888881_1003',
                      'isBusiness': False,
                      'isCustom': False,
                      'isDeleted': False,
                      'isEditable': False,
                      'isIgnored': False,
                      'isUnassignable': False,
                      'isUnbudgetable': False,
                      'isUntrendable': False,
                      'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                   'link': [{'href': '/v1/categories/18888881_1003',
                                             'otherAttributes': {},
                                             'rel': 'self'}]},
                      'name': 'Books & Supplies',
                      'parentId': '18888881_10',
                      'type': 'Category'},
 'Business Services': {'categoryType': 'EXPENSE',
                       'depth': 1,
                       'discretionaryType': 'DISCRETIONARY',
                       'id': '18888881_17',
                       'isBusiness': False,
                       'isCustom': False,
                       'isDeleted': False,
                       'isEditable': False,
                       'isIgnored': False,
                       'isUnassignable': False,
                       'isUnbudgetable': False,
                       'isUntrendable': False,
                       'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                    'link': [{'href': '/v1/categories/18888881_17',
                                              'otherAttributes': {},
                                              'rel': 'self'}]},
                       'name': 'Business Services',
                       'type': 'Category'},
 'Buy': {'categoryType': 'NO_CATEGORY',
         'depth': 2,
         'discretionaryType': 'NONE',
         'id': '18888881_5004',
         'isBusiness': False,
         'isCustom': False,
         'isDeleted': False,
         'isEditable': False,
         'isIgnored': False,
         'isUnassignable': True,
         'isUnbudgetable': True,
         'isUntrendable': True,
         'metaData': {'lastUpdatedDate': '2008-01-01T08:00:00Z',
                      'link': [{'href': '/v1/categories/18888881_5004',
                                'otherAttributes': {},
                                'rel': 'self'}]},
         'name': 'Buy',
         'parentId': '18888881_50',
         'type': 'Category'},
 'Cash & ATM': {'categoryType': 'EXPENSE',
                'depth': 2,
                'discretionaryType': 'DISCRETIONARY',
                'id': '18888881_2001',
                'isBusiness': False,
                'isCustom': False,
                'isDeleted': False,
                'isEditable': False,
                'isIgnored': False,
                'isUnassignable': False,
                'isUnbudgetable': False,
                'isUntrendable': False,
                'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                             'link': [{'href': '/v1/categories/18888881_2001',
                                       'otherAttributes': {},
                                       'rel': 'self'}]},
                'name': 'Cash & ATM',
                'parentId': '18888881_20',
                'type': 'Category'},
 'Charity': {'categoryType': 'EXPENSE',
             'depth': 2,
             'discretionaryType': 'DISCRETIONARY',
             'id': '18888881_802',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': False,
             'isUnbudgetable': False,
             'isUntrendable': False,
             'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                          'link': [{'href': '/v1/categories/18888881_802',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'Charity',
             'parentId': '18888881_8',
             'type': 'Category'},
 'Check': {'categoryType': 'EXPENSE',
           'depth': 2,
           'discretionaryType': 'DISCRETIONARY',
           'id': '18888881_2002',
           'isBusiness': False,
           'isCustom': False,
           'isDeleted': False,
           'isEditable': False,
           'isIgnored': False,
           'isUnassignable': False,
           'isUnbudgetable': False,
           'isUntrendable': False,
           'metaData': {'lastUpdatedDate': '2021-02-10T06:14:23Z',
                        'link': [{'href': '/v1/categories/18888881_2002',
                                  'otherAttributes': {},
                                  'rel': 'self'}]},
           'name': 'Check',
           'parentId': '18888881_20',
           'type': 'Category'},
 'Child Support': {'categoryType': 'EXPENSE',
                   'depth': 2,
                   'discretionaryType': 'NON_DISCRETIONARY',
                   'id': '18888881_603',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                'link': [{'href': '/v1/categories/18888881_603',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Child Support',
                   'parentId': '18888881_6',
                   'type': 'Category'},
 'Clothing': {'categoryType': 'EXPENSE',
              'depth': 2,
              'discretionaryType': 'DISCRETIONARY',
              'id': '18888881_201',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                           'link': [{'href': '/v1/categories/18888881_201',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Clothing',
              'parentId': '18888881_2',
              'type': 'Category'},
 'Coffee Shops': {'categoryType': 'EXPENSE',
                  'depth': 2,
                  'discretionaryType': 'DISCRETIONARY',
                  'id': '18888881_704',
                  'isBusiness': False,
                  'isCustom': False,
                  'isDeleted': False,
                  'isEditable': False,
                  'isIgnored': False,
                  'isUnassignable': False,
                  'isUnbudgetable': False,
                  'isUntrendable': False,
                  'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                               'link': [{'href': '/v1/categories/18888881_704',
                                         'otherAttributes': {},
                                         'rel': 'self'}]},
                  'name': 'Coffee Shops',
                  'parentId': '18888881_7',
                  'type': 'Category'},
 'Credit Card Payment': {'categoryType': 'NO_CATEGORY',
                         'depth': 2,
                         'discretionaryType': 'NONE',
                         'id': '18888881_2101',
                         'isBusiness': False,
                         'isCustom': False,
                         'isDeleted': False,
                         'isEditable': False,
                         'isIgnored': False,
                         'isUnassignable': False,
                         'isUnbudgetable': False,
                         'isUntrendable': True,
                         'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                                      'link': [{'href': '/v1/categories/18888881_2101',
                                                'otherAttributes': {},
                                                'rel': 'self'}]},
                         'name': 'Credit Card Payment',
                         'parentId': '18888881_21',
                         'type': 'Category'},
 'Dentist': {'categoryType': 'EXPENSE',
             'depth': 2,
             'discretionaryType': 'NON_DISCRETIONARY',
             'id': '18888881_501',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': False,
             'isUnbudgetable': False,
             'isUntrendable': False,
             'metaData': {'lastUpdatedDate': '2021-08-20T23:10:57Z',
                          'link': [{'href': '/v1/categories/18888881_501',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'Dentist',
             'parentId': '18888881_5',
             'type': 'Category'},
 'Deposit': {'categoryType': 'NO_CATEGORY',
             'depth': 2,
             'discretionaryType': 'NONE',
             'id': '18888881_5001',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': True,
             'isUnbudgetable': True,
             'isUntrendable': True,
             'metaData': {'lastUpdatedDate': '2008-01-01T08:00:00Z',
                          'link': [{'href': '/v1/categories/18888881_5001',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'Deposit',
             'parentId': '18888881_50',
             'type': 'Category'},
 'Dividend & Cap Gains': {'categoryType': 'NO_CATEGORY',
                          'depth': 2,
                          'discretionaryType': 'NONE',
                          'id': '18888881_5003',
                          'isBusiness': False,
                          'isCustom': False,
                          'isDeleted': False,
                          'isEditable': False,
                          'isIgnored': False,
                          'isUnassignable': True,
                          'isUnbudgetable': True,
                          'isUntrendable': True,
                          'metaData': {'lastUpdatedDate': '2008-01-01T08:00:00Z',
                                       'link': [{'href': '/v1/categories/18888881_5003',
                                                 'otherAttributes': {},
                                                 'rel': 'self'}]},
                          'name': 'Dividend & Cap Gains',
                          'parentId': '18888881_50',
                          'type': 'Category'},
 'Doctor': {'categoryType': 'EXPENSE',
            'depth': 2,
            'discretionaryType': 'NON_DISCRETIONARY',
            'id': '18888881_502',
            'isBusiness': False,
            'isCustom': False,
            'isDeleted': False,
            'isEditable': False,
            'isIgnored': False,
            'isUnassignable': False,
            'isUnbudgetable': False,
            'isUntrendable': False,
            'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                         'link': [{'href': '/v1/categories/18888881_502',
                                   'otherAttributes': {},
                                   'rel': 'self'}]},
            'name': 'Doctor',
            'parentId': '18888881_5',
            'type': 'Category'},
 'Education': {'categoryType': 'EXPENSE',
               'depth': 1,
               'discretionaryType': 'DISCRETIONARY',
               'id': '18888881_10',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                            'link': [{'href': '/v1/categories/18888881_10',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Education',
               'type': 'Category'},
 'Electronics & Software': {'categoryType': 'EXPENSE',
                            'depth': 2,
                            'discretionaryType': 'DISCRETIONARY',
                            'id': '18888881_204',
                            'isBusiness': False,
                            'isCustom': False,
                            'isDeleted': False,
                            'isEditable': False,
                            'isIgnored': False,
                            'isUnassignable': False,
                            'isUnbudgetable': False,
                            'isUntrendable': False,
                            'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                         'link': [{'href': '/v1/categories/18888881_204',
                                                   'otherAttributes': {},
                                                   'rel': 'self'}]},
                            'name': 'Electronics & Software',
                            'parentId': '18888881_2',
                            'type': 'Category'},
 'Entertainment': {'categoryType': 'EXPENSE',
                   'depth': 1,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_1',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                'link': [{'href': '/v1/categories/18888881_1',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Entertainment',
                   'type': 'Category'},
 'Eyecare': {'categoryType': 'EXPENSE',
             'depth': 2,
             'discretionaryType': 'NON_DISCRETIONARY',
             'id': '18888881_503',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': False,
             'isUnbudgetable': False,
             'isUntrendable': False,
             'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                          'link': [{'href': '/v1/categories/18888881_503',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'Eyecare',
             'parentId': '18888881_5',
             'type': 'Category'},
 'Fast Food': {'categoryType': 'EXPENSE',
               'depth': 2,
               'discretionaryType': 'DISCRETIONARY',
               'id': '18888881_706',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                            'link': [{'href': '/v1/categories/18888881_706',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Fast Food',
               'parentId': '18888881_7',
               'type': 'Category'},
 'Federal Tax': {'categoryType': 'EXPENSE',
                 'depth': 2,
                 'discretionaryType': 'NON_DISCRETIONARY',
                 'id': '18888881_1901',
                 'isBusiness': False,
                 'isCustom': False,
                 'isDeleted': False,
                 'isEditable': False,
                 'isIgnored': False,
                 'isUnassignable': False,
                 'isUnbudgetable': False,
                 'isUntrendable': False,
                 'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                              'link': [{'href': '/v1/categories/18888881_1901',
                                        'otherAttributes': {},
                                        'rel': 'self'}]},
                 'name': 'Federal Tax',
                 'parentId': '18888881_19',
                 'type': 'Category'},
 'Fees & Charges': {'categoryType': 'EXPENSE',
                    'depth': 1,
                    'discretionaryType': 'NON_DISCRETIONARY',
                    'id': '18888881_16',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': False,
                    'isUnbudgetable': False,
                    'isUntrendable': False,
                    'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                 'link': [{'href': '/v1/categories/18888881_16',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Fees & Charges',
                    'type': 'Category'},
 'Finance Charge': {'categoryType': 'EXPENSE',
                    'depth': 2,
                    'discretionaryType': 'NON_DISCRETIONARY',
                    'id': '18888881_1604',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': False,
                    'isUnbudgetable': False,
                    'isUntrendable': False,
                    'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                 'link': [{'href': '/v1/categories/18888881_1604',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Finance Charge',
                    'parentId': '18888881_16',
                    'type': 'Category'},
 'Financial': {'categoryType': 'EXPENSE',
               'depth': 1,
               'discretionaryType': 'NON_DISCRETIONARY',
               'id': '18888881_11',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                            'link': [{'href': '/v1/categories/18888881_11',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Financial',
               'type': 'Category'},
 'Financial Advisor': {'categoryType': 'EXPENSE',
                       'depth': 2,
                       'discretionaryType': 'DISCRETIONARY',
                       'id': '18888881_1105',
                       'isBusiness': False,
                       'isCustom': False,
                       'isDeleted': False,
                       'isEditable': False,
                       'isIgnored': False,
                       'isUnassignable': False,
                       'isUnbudgetable': False,
                       'isUntrendable': False,
                       'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                    'link': [{'href': '/v1/categories/18888881_1105',
                                              'otherAttributes': {},
                                              'rel': 'self'}]},
                       'name': 'Financial Advisor',
                       'parentId': '18888881_11',
                       'type': 'Category'},
 'Food & Dining': {'categoryType': 'EXPENSE',
                   'depth': 1,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_7',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                'link': [{'href': '/v1/categories/18888881_7',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Food & Dining',
                   'type': 'Category'},
 'Food Delivery': {'categoryType': 'EXPENSE',
                   'depth': 2,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_709',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2021-10-29T08:19:03Z',
                                'link': [{'href': '/v1/categories/18888881_709',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Food Delivery',
                   'parentId': '18888881_7',
                   'type': 'Category'},
 'Furnishings': {'categoryType': 'EXPENSE',
                 'depth': 2,
                 'discretionaryType': 'DISCRETIONARY',
                 'id': '18888881_1201',
                 'isBusiness': False,
                 'isCustom': False,
                 'isDeleted': False,
                 'isEditable': False,
                 'isIgnored': False,
                 'isUnassignable': False,
                 'isUnbudgetable': False,
                 'isUntrendable': False,
                 'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                              'link': [{'href': '/v1/categories/18888881_1201',
                                        'otherAttributes': {},
                                        'rel': 'self'}]},
                 'name': 'Furnishings',
                 'parentId': '18888881_12',
                 'type': 'Category'},
 'Gas & Fuel': {'categoryType': 'EXPENSE',
                'depth': 2,
                'discretionaryType': 'NON_DISCRETIONARY',
                'id': '18888881_1401',
                'isBusiness': False,
                'isCustom': False,
                'isDeleted': False,
                'isEditable': False,
                'isIgnored': False,
                'isUnassignable': False,
                'isUnbudgetable': False,
                'isUntrendable': False,
                'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                             'link': [{'href': '/v1/categories/18888881_1401',
                                       'otherAttributes': {},
                                       'rel': 'self'}]},
                'name': 'Gas & Fuel',
                'parentId': '18888881_14',
                'type': 'Category'},
 'Gift': {'categoryType': 'EXPENSE',
          'depth': 2,
          'discretionaryType': 'DISCRETIONARY',
          'id': '18888881_801',
          'isBusiness': False,
          'isCustom': False,
          'isDeleted': False,
          'isEditable': False,
          'isIgnored': False,
          'isUnassignable': False,
          'isUnbudgetable': False,
          'isUntrendable': False,
          'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                       'link': [{'href': '/v1/categories/18888881_801',
                                 'otherAttributes': {},
                                 'rel': 'self'}]},
          'name': 'Gift',
          'parentId': '18888881_8',
          'type': 'Category'},
 'Gifts & Donations': {'categoryType': 'EXPENSE',
                       'depth': 1,
                       'discretionaryType': 'DISCRETIONARY',
                       'id': '18888881_8',
                       'isBusiness': False,
                       'isCustom': False,
                       'isDeleted': False,
                       'isEditable': False,
                       'isIgnored': False,
                       'isUnassignable': False,
                       'isUnbudgetable': False,
                       'isUntrendable': False,
                       'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                    'link': [{'href': '/v1/categories/18888881_8',
                                              'otherAttributes': {},
                                              'rel': 'self'}]},
                       'name': 'Gifts & Donations',
                       'type': 'Category'},
 'Groceries': {'categoryType': 'EXPENSE',
               'depth': 2,
               'discretionaryType': 'NON_DISCRETIONARY',
               'id': '18888881_701',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                            'link': [{'href': '/v1/categories/18888881_701',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Groceries',
               'parentId': '18888881_7',
               'type': 'Category'},
 'Gym': {'categoryType': 'EXPENSE',
         'depth': 2,
         'discretionaryType': 'DISCRETIONARY',
         'id': '18888881_507',
         'isBusiness': False,
         'isCustom': False,
         'isDeleted': False,
         'isEditable': False,
         'isIgnored': False,
         'isUnassignable': False,
         'isUnbudgetable': False,
         'isUntrendable': False,
         'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                      'link': [{'href': '/v1/categories/18888881_507',
                                'otherAttributes': {},
                                'rel': 'self'}]},
         'name': 'Gym',
         'parentId': '18888881_5',
         'type': 'Category'},
 'Hair': {'categoryType': 'EXPENSE',
          'depth': 2,
          'discretionaryType': 'DISCRETIONARY',
          'id': '18888881_403',
          'isBusiness': False,
          'isCustom': False,
          'isDeleted': False,
          'isEditable': False,
          'isIgnored': False,
          'isUnassignable': False,
          'isUnbudgetable': False,
          'isUntrendable': False,
          'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                       'link': [{'href': '/v1/categories/18888881_403',
                                 'otherAttributes': {},
                                 'rel': 'self'}]},
          'name': 'Hair',
          'parentId': '18888881_4',
          'type': 'Category'},
 'Health & Fitness': {'categoryType': 'EXPENSE',
                      'depth': 1,
                      'discretionaryType': 'DISCRETIONARY',
                      'id': '18888881_5',
                      'isBusiness': False,
                      'isCustom': False,
                      'isDeleted': False,
                      'isEditable': False,
                      'isIgnored': False,
                      'isUnassignable': False,
                      'isUnbudgetable': False,
                      'isUntrendable': False,
                      'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                   'link': [{'href': '/v1/categories/18888881_5',
                                             'otherAttributes': {},
                                             'rel': 'self'}]},
                      'name': 'Health & Fitness',
                      'type': 'Category'},
 'Health Insurance': {'categoryType': 'EXPENSE',
                      'depth': 2,
                      'discretionaryType': 'NON_DISCRETIONARY',
                      'id': '18888881_506',
                      'isBusiness': False,
                      'isCustom': False,
                      'isDeleted': False,
                      'isEditable': False,
                      'isIgnored': False,
                      'isUnassignable': False,
                      'isUnbudgetable': False,
                      'isUntrendable': False,
                      'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                   'link': [{'href': '/v1/categories/18888881_506',
                                             'otherAttributes': {},
                                             'rel': 'self'}]},
                      'name': 'Health Insurance',
                      'parentId': '18888881_5',
                      'type': 'Category'},
 'Hide from Budgets & Trends': {'categoryType': 'NO_CATEGORY',
                                'depth': 1,
                                'discretionaryType': 'NONE',
                                'id': '18888881_40',
                                'isBusiness': False,
                                'isCustom': False,
                                'isDeleted': False,
                                'isEditable': False,
                                'isIgnored': True,
                                'isUnassignable': False,
                                'isUnbudgetable': True,
                                'isUntrendable': True,
                                'metaData': {'lastUpdatedDate': '2013-10-22T08:07:13Z',
                                             'link': [{'href': '/v1/categories/18888881_40',
                                                       'otherAttributes': {},
                                                       'rel': 'self'}]},
                                'name': 'Hide from Budgets & Trends',
                                'type': 'Category'},
 'Hobbies': {'categoryType': 'EXPENSE',
             'depth': 2,
             'discretionaryType': 'DISCRETIONARY',
             'id': '18888881_206',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': False,
             'isUnbudgetable': False,
             'isUntrendable': False,
             'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                          'link': [{'href': '/v1/categories/18888881_206',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'Hobbies',
             'parentId': '18888881_2',
             'type': 'Category'},
 'Home': {'categoryType': 'EXPENSE',
          'depth': 1,
          'discretionaryType': 'DISCRETIONARY',
          'id': '18888881_12',
          'isBusiness': False,
          'isCustom': False,
          'isDeleted': False,
          'isEditable': False,
          'isIgnored': False,
          'isUnassignable': False,
          'isUnbudgetable': False,
          'isUntrendable': False,
          'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                       'link': [{'href': '/v1/categories/18888881_12',
                                 'otherAttributes': {},
                                 'rel': 'self'}]},
          'name': 'Home',
          'type': 'Category'},
 'Home Improvement': {'categoryType': 'EXPENSE',
                      'depth': 2,
                      'discretionaryType': 'DISCRETIONARY',
                      'id': '18888881_1203',
                      'isBusiness': False,
                      'isCustom': False,
                      'isDeleted': False,
                      'isEditable': False,
                      'isIgnored': False,
                      'isUnassignable': False,
                      'isUnbudgetable': False,
                      'isUntrendable': False,
                      'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                   'link': [{'href': '/v1/categories/18888881_1203',
                                             'otherAttributes': {},
                                             'rel': 'self'}]},
                      'name': 'Home Improvement',
                      'parentId': '18888881_12',
                      'type': 'Category'},
 'Home Insurance': {'categoryType': 'EXPENSE',
                    'depth': 2,
                    'discretionaryType': 'NON_DISCRETIONARY',
                    'id': '18888881_1206',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': False,
                    'isUnbudgetable': False,
                    'isUntrendable': False,
                    'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                                 'link': [{'href': '/v1/categories/18888881_1206',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Home Insurance',
                    'parentId': '18888881_12',
                    'type': 'Category'},
 'Home Phone': {'categoryType': 'EXPENSE',
                'depth': 2,
                'discretionaryType': 'NON_DISCRETIONARY',
                'id': '18888881_1302',
                'isBusiness': False,
                'isCustom': False,
                'isDeleted': False,
                'isEditable': False,
                'isIgnored': False,
                'isUnassignable': False,
                'isUnbudgetable': False,
                'isUntrendable': False,
                'metaData': {'lastUpdatedDate': '2020-11-18T07:31:47Z',
                             'link': [{'href': '/v1/categories/18888881_1302',
                                       'otherAttributes': {},
                                       'rel': 'self'}]},
                'name': 'Home Phone',
                'parentId': '18888881_13',
                'type': 'Category'},
 'Home Services': {'categoryType': 'EXPENSE',
                   'depth': 2,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_1204',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                'link': [{'href': '/v1/categories/18888881_1204',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Home Services',
                   'parentId': '18888881_12',
                   'type': 'Category'},
 'Home Supplies': {'categoryType': 'EXPENSE',
                   'depth': 2,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_1208',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                'link': [{'href': '/v1/categories/18888881_1208',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Home Supplies',
                   'parentId': '18888881_12',
                   'type': 'Category'},
 'Hotel': {'categoryType': 'EXPENSE',
           'depth': 2,
           'discretionaryType': 'DISCRETIONARY',
           'id': '18888881_1502',
           'isBusiness': False,
           'isCustom': False,
           'isDeleted': False,
           'isEditable': False,
           'isIgnored': False,
           'isUnassignable': False,
           'isUnbudgetable': False,
           'isUntrendable': False,
           'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                        'link': [{'href': '/v1/categories/18888881_1502',
                                  'otherAttributes': {},
                                  'rel': 'self'}]},
           'name': 'Hotel',
           'parentId': '18888881_15',
           'type': 'Category'},
 'Income': {'categoryType': 'INCOME',
            'depth': 1,
            'discretionaryType': 'NONE',
            'id': '18888881_30',
            'isBusiness': False,
            'isCustom': False,
            'isDeleted': False,
            'isEditable': False,
            'isIgnored': False,
            'isUnassignable': False,
            'isUnbudgetable': False,
            'isUntrendable': False,
            'metaData': {'lastUpdatedDate': '2013-07-12T05:39:16Z',
                         'link': [{'href': '/v1/categories/18888881_30',
                                   'otherAttributes': {},
                                   'rel': 'self'}]},
            'name': 'Income',
            'type': 'Category'},
 'Interest Income': {'categoryType': 'INCOME',
                     'depth': 2,
                     'discretionaryType': 'NONE',
                     'id': '18888881_3005',
                     'isBusiness': False,
                     'isCustom': False,
                     'isDeleted': False,
                     'isEditable': False,
                     'isIgnored': False,
                     'isUnassignable': False,
                     'isUnbudgetable': False,
                     'isUntrendable': False,
                     'metaData': {'lastUpdatedDate': '2013-07-12T05:39:16Z',
                                  'link': [{'href': '/v1/categories/18888881_3005',
                                            'otherAttributes': {},
                                            'rel': 'self'}]},
                     'name': 'Interest Income',
                     'parentId': '18888881_30',
                     'type': 'Category'},
 'Internet': {'categoryType': 'EXPENSE',
              'depth': 2,
              'discretionaryType': 'NON_DISCRETIONARY',
              'id': '18888881_1303',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                           'link': [{'href': '/v1/categories/18888881_1303',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Internet',
              'parentId': '18888881_13',
              'type': 'Category'},
 'Investments': {'categoryType': 'NO_CATEGORY',
                 'depth': 1,
                 'discretionaryType': 'NONE',
                 'id': '18888881_50',
                 'isBusiness': False,
                 'isCustom': False,
                 'isDeleted': False,
                 'isEditable': False,
                 'isIgnored': False,
                 'isUnassignable': True,
                 'isUnbudgetable': True,
                 'isUntrendable': True,
                 'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                              'link': [{'href': '/v1/categories/18888881_50',
                                        'otherAttributes': {},
                                        'rel': 'self'}]},
                 'name': 'Investments',
                 'type': 'Category'},
 'Kids': {'categoryType': 'EXPENSE',
          'depth': 1,
          'discretionaryType': 'DISCRETIONARY',
          'id': '18888881_6',
          'isBusiness': False,
          'isCustom': False,
          'isDeleted': False,
          'isEditable': False,
          'isIgnored': False,
          'isUnassignable': False,
          'isUnbudgetable': False,
          'isUntrendable': False,
          'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                       'link': [{'href': '/v1/categories/18888881_6',
                                 'otherAttributes': {},
                                 'rel': 'self'}]},
          'name': 'Kids',
          'type': 'Category'},
 'Kids Activities': {'categoryType': 'EXPENSE',
                     'depth': 2,
                     'discretionaryType': 'DISCRETIONARY',
                     'id': '18888881_609',
                     'isBusiness': False,
                     'isCustom': False,
                     'isDeleted': False,
                     'isEditable': False,
                     'isIgnored': False,
                     'isUnassignable': False,
                     'isUnbudgetable': False,
                     'isUntrendable': False,
                     'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                  'link': [{'href': '/v1/categories/18888881_609',
                                            'otherAttributes': {},
                                            'rel': 'self'}]},
                     'name': 'Kids Activities',
                     'parentId': '18888881_6',
                     'type': 'Category'},
 'Late Fee': {'categoryType': 'EXPENSE',
              'depth': 2,
              'discretionaryType': 'DISCRETIONARY',
              'id': '18888881_1602',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                           'link': [{'href': '/v1/categories/18888881_1602',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Late Fee',
              'parentId': '18888881_16',
              'type': 'Category'},
 'Laundry': {'categoryType': 'EXPENSE',
             'depth': 2,
             'discretionaryType': 'NON_DISCRETIONARY',
             'id': '18888881_406',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': False,
             'isUnbudgetable': False,
             'isUntrendable': False,
             'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                          'link': [{'href': '/v1/categories/18888881_406',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'Laundry',
             'parentId': '18888881_4',
             'type': 'Category'},
 'Lawn & Garden': {'categoryType': 'EXPENSE',
                   'depth': 2,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_1202',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                'link': [{'href': '/v1/categories/18888881_1202',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Lawn & Garden',
                   'parentId': '18888881_12',
                   'type': 'Category'},
 'Legal': {'categoryType': 'EXPENSE',
           'depth': 2,
           'discretionaryType': 'NON_DISCRETIONARY',
           'id': '18888881_1705',
           'isBusiness': False,
           'isCustom': False,
           'isDeleted': False,
           'isEditable': False,
           'isIgnored': False,
           'isUnassignable': False,
           'isUnbudgetable': False,
           'isUntrendable': False,
           'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                        'link': [{'href': '/v1/categories/18888881_1705',
                                  'otherAttributes': {},
                                  'rel': 'self'}]},
           'name': 'Legal',
           'parentId': '18888881_17',
           'type': 'Category'},
 'Life Insurance': {'categoryType': 'EXPENSE',
                    'depth': 2,
                    'discretionaryType': 'NON_DISCRETIONARY',
                    'id': '18888881_1102',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': False,
                    'isUnbudgetable': False,
                    'isUntrendable': False,
                    'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                 'link': [{'href': '/v1/categories/18888881_1102',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Life Insurance',
                    'parentId': '18888881_11',
                    'type': 'Category'},
 'Loan Fees and Charges': {'categoryType': 'NO_CATEGORY',
                           'depth': 2,
                           'discretionaryType': 'NONE',
                           'id': '18888881_6005',
                           'isBusiness': False,
                           'isCustom': False,
                           'isDeleted': False,
                           'isEditable': False,
                           'isIgnored': False,
                           'isUnassignable': True,
                           'isUnbudgetable': True,
                           'isUntrendable': True,
                           'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                                        'link': [{'href': '/v1/categories/18888881_6005',
                                                  'otherAttributes': {},
                                                  'rel': 'self'}]},
                           'name': 'Loan Fees and Charges',
                           'parentId': '18888881_60',
                           'type': 'Category'},
 'Loan Insurance': {'categoryType': 'NO_CATEGORY',
                    'depth': 2,
                    'discretionaryType': 'NONE',
                    'id': '18888881_6002',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': True,
                    'isUnbudgetable': True,
                    'isUntrendable': True,
                    'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                                 'link': [{'href': '/v1/categories/18888881_6002',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Loan Insurance',
                    'parentId': '18888881_60',
                    'type': 'Category'},
 'Loan Interest': {'categoryType': 'NO_CATEGORY',
                   'depth': 2,
                   'discretionaryType': 'NONE',
                   'id': '18888881_6004',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': True,
                   'isUnbudgetable': True,
                   'isUntrendable': True,
                   'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                                'link': [{'href': '/v1/categories/18888881_6004',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Loan Interest',
                   'parentId': '18888881_60',
                   'type': 'Category'},
 'Loan Payment': {'categoryType': 'NO_CATEGORY',
                  'depth': 2,
                  'discretionaryType': 'NONE',
                  'id': '18888881_6001',
                  'isBusiness': False,
                  'isCustom': False,
                  'isDeleted': False,
                  'isEditable': False,
                  'isIgnored': False,
                  'isUnassignable': True,
                  'isUnbudgetable': True,
                  'isUntrendable': True,
                  'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                               'link': [{'href': '/v1/categories/18888881_6001',
                                         'otherAttributes': {},
                                         'rel': 'self'}]},
                  'name': 'Loan Payment',
                  'parentId': '18888881_60',
                  'type': 'Category'},
 'Loan Principal': {'categoryType': 'NO_CATEGORY',
                    'depth': 2,
                    'discretionaryType': 'NONE',
                    'id': '18888881_6003',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': True,
                    'isUnbudgetable': True,
                    'isUntrendable': True,
                    'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                                 'link': [{'href': '/v1/categories/18888881_6003',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Loan Principal',
                    'parentId': '18888881_60',
                    'type': 'Category'},
 'Loans': {'categoryType': 'NO_CATEGORY',
           'depth': 1,
           'discretionaryType': 'NONE',
           'id': '18888881_60',
           'isBusiness': False,
           'isCustom': False,
           'isDeleted': False,
           'isEditable': False,
           'isIgnored': False,
           'isUnassignable': True,
           'isUnbudgetable': True,
           'isUntrendable': True,
           'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                        'link': [{'href': '/v1/categories/18888881_60',
                                  'otherAttributes': {},
                                  'rel': 'self'}]},
           'name': 'Loans',
           'type': 'Category'},
 'Local Tax': {'categoryType': 'EXPENSE',
               'depth': 2,
               'discretionaryType': 'NON_DISCRETIONARY',
               'id': '18888881_1903',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                            'link': [{'href': '/v1/categories/18888881_1903',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Local Tax',
               'parentId': '18888881_19',
               'type': 'Category'},
 'Misc Expenses': {'categoryType': 'EXPENSE',
                   'depth': 1,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_70',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2021-02-09T06:59:38Z',
                                'link': [{'href': '/v1/categories/18888881_70',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Misc Expenses',
                   'type': 'Category'},
 'Mobile Phone': {'categoryType': 'EXPENSE',
                  'depth': 2,
                  'discretionaryType': 'NON_DISCRETIONARY',
                  'id': '18888881_1304',
                  'isBusiness': False,
                  'isCustom': False,
                  'isDeleted': False,
                  'isEditable': False,
                  'isIgnored': False,
                  'isUnassignable': False,
                  'isUnbudgetable': False,
                  'isUntrendable': False,
                  'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                               'link': [{'href': '/v1/categories/18888881_1304',
                                         'otherAttributes': {},
                                         'rel': 'self'}]},
                  'name': 'Mobile Phone',
                  'parentId': '18888881_13',
                  'type': 'Category'},
 'Mortgage & Rent': {'categoryType': 'EXPENSE',
                     'depth': 2,
                     'discretionaryType': 'NON_DISCRETIONARY',
                     'id': '18888881_1207',
                     'isBusiness': False,
                     'isCustom': False,
                     'isDeleted': False,
                     'isEditable': False,
                     'isIgnored': False,
                     'isUnassignable': False,
                     'isUnbudgetable': False,
                     'isUntrendable': False,
                     'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                  'link': [{'href': '/v1/categories/18888881_1207',
                                            'otherAttributes': {},
                                            'rel': 'self'}]},
                     'name': 'Mortgage & Rent',
                     'parentId': '18888881_12',
                     'type': 'Category'},
 'Movies & DVDs': {'categoryType': 'EXPENSE',
                   'depth': 2,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_104',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                'link': [{'href': '/v1/categories/18888881_104',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Movies & DVDs',
                   'parentId': '18888881_1',
                   'type': 'Category'},
 'Music': {'categoryType': 'EXPENSE',
           'depth': 2,
           'discretionaryType': 'DISCRETIONARY',
           'id': '18888881_103',
           'isBusiness': False,
           'isCustom': False,
           'isDeleted': False,
           'isEditable': False,
           'isIgnored': False,
           'isUnassignable': False,
           'isUnbudgetable': False,
           'isUntrendable': False,
           'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                        'link': [{'href': '/v1/categories/18888881_103',
                                  'otherAttributes': {},
                                  'rel': 'self'}]},
           'name': 'Music',
           'parentId': '18888881_1',
           'type': 'Category'},
 'Newspapers & Magazines': {'categoryType': 'EXPENSE',
                            'depth': 2,
                            'discretionaryType': 'DISCRETIONARY',
                            'id': '18888881_105',
                            'isBusiness': False,
                            'isCustom': False,
                            'isDeleted': False,
                            'isEditable': False,
                            'isIgnored': False,
                            'isUnassignable': False,
                            'isUnbudgetable': False,
                            'isUntrendable': False,
                            'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                         'link': [{'href': '/v1/categories/18888881_105',
                                                   'otherAttributes': {},
                                                   'rel': 'self'}]},
                            'name': 'Newspapers & Magazines',
                            'parentId': '18888881_1',
                            'type': 'Category'},
 'Office Supplies': {'categoryType': 'EXPENSE',
                     'depth': 2,
                     'discretionaryType': 'NON_DISCRETIONARY',
                     'id': '18888881_1702',
                     'isBusiness': False,
                     'isCustom': False,
                     'isDeleted': False,
                     'isEditable': False,
                     'isIgnored': False,
                     'isUnassignable': False,
                     'isUnbudgetable': False,
                     'isUntrendable': False,
                     'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                  'link': [{'href': '/v1/categories/18888881_1702',
                                            'otherAttributes': {},
                                            'rel': 'self'}]},
                     'name': 'Office Supplies',
                     'parentId': '18888881_17',
                     'type': 'Category'},
 'Parking': {'categoryType': 'EXPENSE',
             'depth': 2,
             'discretionaryType': 'DISCRETIONARY',
             'id': '18888881_1402',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': False,
             'isUnbudgetable': False,
             'isUntrendable': False,
             'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                          'link': [{'href': '/v1/categories/18888881_1402',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'Parking',
             'parentId': '18888881_14',
             'type': 'Category'},
 'Paycheck': {'categoryType': 'INCOME',
              'depth': 2,
              'discretionaryType': 'NONE',
              'id': '18888881_3001',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2013-07-12T05:39:16Z',
                           'link': [{'href': '/v1/categories/18888881_3001',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Paycheck',
              'parentId': '18888881_30',
              'type': 'Category'},
 'Personal Care': {'categoryType': 'EXPENSE',
                   'depth': 1,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_4',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                'link': [{'href': '/v1/categories/18888881_4',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Personal Care',
                   'type': 'Category'},
 'Pet Food & Supplies': {'categoryType': 'EXPENSE',
                         'depth': 2,
                         'discretionaryType': 'NON_DISCRETIONARY',
                         'id': '18888881_901',
                         'isBusiness': False,
                         'isCustom': False,
                         'isDeleted': False,
                         'isEditable': False,
                         'isIgnored': False,
                         'isUnassignable': False,
                         'isUnbudgetable': False,
                         'isUntrendable': False,
                         'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                      'link': [{'href': '/v1/categories/18888881_901',
                                                'otherAttributes': {},
                                                'rel': 'self'}]},
                         'name': 'Pet Food & Supplies',
                         'parentId': '18888881_9',
                         'type': 'Category'},
 'Pet Grooming': {'categoryType': 'EXPENSE',
                  'depth': 2,
                  'discretionaryType': 'DISCRETIONARY',
                  'id': '18888881_902',
                  'isBusiness': False,
                  'isCustom': False,
                  'isDeleted': False,
                  'isEditable': False,
                  'isIgnored': False,
                  'isUnassignable': False,
                  'isUnbudgetable': False,
                  'isUntrendable': False,
                  'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                               'link': [{'href': '/v1/categories/18888881_902',
                                         'otherAttributes': {},
                                         'rel': 'self'}]},
                  'name': 'Pet Grooming',
                  'parentId': '18888881_9',
                  'type': 'Category'},
 'Pets': {'categoryType': 'EXPENSE',
          'depth': 1,
          'discretionaryType': 'DISCRETIONARY',
          'id': '18888881_9',
          'isBusiness': False,
          'isCustom': False,
          'isDeleted': False,
          'isEditable': False,
          'isIgnored': False,
          'isUnassignable': False,
          'isUnbudgetable': False,
          'isUntrendable': False,
          'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                       'link': [{'href': '/v1/categories/18888881_9',
                                 'otherAttributes': {},
                                 'rel': 'self'}]},
          'name': 'Pets',
          'type': 'Category'},
 'Pharmacy': {'categoryType': 'EXPENSE',
              'depth': 2,
              'discretionaryType': 'NON_DISCRETIONARY',
              'id': '18888881_505',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2021-08-20T23:10:49Z',
                           'link': [{'href': '/v1/categories/18888881_505',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Pharmacy',
              'parentId': '18888881_5',
              'type': 'Category'},
 'Printing': {'categoryType': 'EXPENSE',
              'depth': 2,
              'discretionaryType': 'NON_DISCRETIONARY',
              'id': '18888881_1703',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                           'link': [{'href': '/v1/categories/18888881_1703',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Printing',
              'parentId': '18888881_17',
              'type': 'Category'},
 'Property Tax': {'categoryType': 'EXPENSE',
                  'depth': 2,
                  'discretionaryType': 'NON_DISCRETIONARY',
                  'id': '18888881_1905',
                  'isBusiness': False,
                  'isCustom': False,
                  'isDeleted': False,
                  'isEditable': False,
                  'isIgnored': False,
                  'isUnassignable': False,
                  'isUnbudgetable': False,
                  'isUntrendable': False,
                  'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                               'link': [{'href': '/v1/categories/18888881_1905',
                                         'otherAttributes': {},
                                         'rel': 'self'}]},
                  'name': 'Property Tax',
                  'parentId': '18888881_19',
                  'type': 'Category'},
 'Public Transportation': {'categoryType': 'EXPENSE',
                           'depth': 2,
                           'discretionaryType': 'NON_DISCRETIONARY',
                           'id': '18888881_1406',
                           'isBusiness': False,
                           'isCustom': False,
                           'isDeleted': False,
                           'isEditable': False,
                           'isIgnored': False,
                           'isUnassignable': False,
                           'isUnbudgetable': False,
                           'isUntrendable': False,
                           'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                        'link': [{'href': '/v1/categories/18888881_1406',
                                                  'otherAttributes': {},
                                                  'rel': 'self'}]},
                           'name': 'Public Transportation',
                           'parentId': '18888881_14',
                           'type': 'Category'},
 'Reimbursement': {'categoryType': 'INCOME',
                   'depth': 2,
                   'discretionaryType': 'NONE',
                   'id': '18888881_3006',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2013-07-12T05:39:16Z',
                                'link': [{'href': '/v1/categories/18888881_3006',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Reimbursement',
                   'parentId': '18888881_30',
                   'type': 'Category'},
 'Rental Car & Taxi': {'categoryType': 'EXPENSE',
                       'depth': 2,
                       'discretionaryType': 'DISCRETIONARY',
                       'id': '18888881_1503',
                       'isBusiness': False,
                       'isCustom': False,
                       'isDeleted': False,
                       'isEditable': False,
                       'isIgnored': False,
                       'isUnassignable': False,
                       'isUnbudgetable': False,
                       'isUntrendable': False,
                       'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                    'link': [{'href': '/v1/categories/18888881_1503',
                                              'otherAttributes': {},
                                              'rel': 'self'}]},
                       'name': 'Rental Car & Taxi',
                       'parentId': '18888881_15',
                       'type': 'Category'},
 'Rental Income': {'categoryType': 'INCOME',
                   'depth': 2,
                   'discretionaryType': 'NONE',
                   'id': '18888881_3007',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2013-07-12T05:39:16Z',
                                'link': [{'href': '/v1/categories/18888881_3007',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Rental Income',
                   'parentId': '18888881_30',
                   'type': 'Category'},
 'Restaurants': {'categoryType': 'EXPENSE',
                 'depth': 2,
                 'discretionaryType': 'DISCRETIONARY',
                 'id': '18888881_707',
                 'isBusiness': False,
                 'isCustom': False,
                 'isDeleted': False,
                 'isEditable': False,
                 'isIgnored': False,
                 'isUnassignable': False,
                 'isUnbudgetable': False,
                 'isUntrendable': False,
                 'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                              'link': [{'href': '/v1/categories/18888881_707',
                                        'otherAttributes': {},
                                        'rel': 'self'}]},
                 'name': 'Restaurants',
                 'parentId': '18888881_7',
                 'type': 'Category'},
 'Returned Purchase': {'categoryType': 'INCOME',
                       'depth': 2,
                       'discretionaryType': 'NONE',
                       'id': '18888881_3003',
                       'isBusiness': False,
                       'isCustom': False,
                       'isDeleted': False,
                       'isEditable': False,
                       'isIgnored': False,
                       'isUnassignable': False,
                       'isUnbudgetable': False,
                       'isUntrendable': False,
                       'metaData': {'lastUpdatedDate': '2013-07-12T05:39:16Z',
                                    'link': [{'href': '/v1/categories/18888881_3003',
                                              'otherAttributes': {},
                                              'rel': 'self'}]},
                       'name': 'Returned Purchase',
                       'parentId': '18888881_30',
                       'type': 'Category'},
 'Ride Share': {'categoryType': 'EXPENSE',
                'depth': 2,
                'discretionaryType': 'DISCRETIONARY',
                'id': '18888881_1408',
                'isBusiness': False,
                'isCustom': False,
                'isDeleted': False,
                'isEditable': False,
                'isIgnored': False,
                'isUnassignable': False,
                'isUnbudgetable': False,
                'isUntrendable': False,
                'metaData': {'lastUpdatedDate': '2021-10-29T08:19:05Z',
                             'link': [{'href': '/v1/categories/18888881_1408',
                                       'otherAttributes': {},
                                       'rel': 'self'}]},
                'name': 'Ride Share',
                'parentId': '18888881_14',
                'type': 'Category'},
 'Sales Tax': {'categoryType': 'EXPENSE',
               'depth': 2,
               'discretionaryType': 'NON_DISCRETIONARY',
               'id': '18888881_1904',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                            'link': [{'href': '/v1/categories/18888881_1904',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Sales Tax',
               'parentId': '18888881_19',
               'type': 'Category'},
 'Sell': {'categoryType': 'NO_CATEGORY',
          'depth': 2,
          'discretionaryType': 'NONE',
          'id': '18888881_5005',
          'isBusiness': False,
          'isCustom': False,
          'isDeleted': False,
          'isEditable': False,
          'isIgnored': False,
          'isUnassignable': True,
          'isUnbudgetable': True,
          'isUntrendable': True,
          'metaData': {'lastUpdatedDate': '2008-01-01T08:00:00Z',
                       'link': [{'href': '/v1/categories/18888881_5005',
                                 'otherAttributes': {},
                                 'rel': 'self'}]},
          'name': 'Sell',
          'parentId': '18888881_50',
          'type': 'Category'},
 'Service & Parts': {'categoryType': 'EXPENSE',
                     'depth': 2,
                     'discretionaryType': 'NON_DISCRETIONARY',
                     'id': '18888881_1403',
                     'isBusiness': False,
                     'isCustom': False,
                     'isDeleted': False,
                     'isEditable': False,
                     'isIgnored': False,
                     'isUnassignable': False,
                     'isUnbudgetable': False,
                     'isUntrendable': False,
                     'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                  'link': [{'href': '/v1/categories/18888881_1403',
                                            'otherAttributes': {},
                                            'rel': 'self'}]},
                     'name': 'Service & Parts',
                     'parentId': '18888881_14',
                     'type': 'Category'},
 'Service Fee': {'categoryType': 'EXPENSE',
                 'depth': 2,
                 'discretionaryType': 'NON_DISCRETIONARY',
                 'id': '18888881_1601',
                 'isBusiness': False,
                 'isCustom': False,
                 'isDeleted': False,
                 'isEditable': False,
                 'isIgnored': False,
                 'isUnassignable': False,
                 'isUnbudgetable': False,
                 'isUntrendable': False,
                 'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                              'link': [{'href': '/v1/categories/18888881_1601',
                                        'otherAttributes': {},
                                        'rel': 'self'}]},
                 'name': 'Service Fee',
                 'parentId': '18888881_16',
                 'type': 'Category'},
 'Shipping': {'categoryType': 'EXPENSE',
              'depth': 2,
              'discretionaryType': 'NON_DISCRETIONARY',
              'id': '18888881_1704',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                           'link': [{'href': '/v1/categories/18888881_1704',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Shipping',
              'parentId': '18888881_17',
              'type': 'Category'},
 'Shopping': {'categoryType': 'EXPENSE',
              'depth': 1,
              'discretionaryType': 'DISCRETIONARY',
              'id': '18888881_2',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                           'link': [{'href': '/v1/categories/18888881_2',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Shopping',
              'type': 'Category'},
 'Spa & Massage': {'categoryType': 'EXPENSE',
                   'depth': 2,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_404',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                'link': [{'href': '/v1/categories/18888881_404',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Spa & Massage',
                   'parentId': '18888881_4',
                   'type': 'Category'},
 'Sporting Goods': {'categoryType': 'EXPENSE',
                    'depth': 2,
                    'discretionaryType': 'DISCRETIONARY',
                    'id': '18888881_207',
                    'isBusiness': False,
                    'isCustom': False,
                    'isDeleted': False,
                    'isEditable': False,
                    'isIgnored': False,
                    'isUnassignable': False,
                    'isUnbudgetable': False,
                    'isUntrendable': False,
                    'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                 'link': [{'href': '/v1/categories/18888881_207',
                                           'otherAttributes': {},
                                           'rel': 'self'}]},
                    'name': 'Sporting Goods',
                    'parentId': '18888881_2',
                    'type': 'Category'},
 'Sports': {'categoryType': 'EXPENSE',
            'depth': 2,
            'discretionaryType': 'DISCRETIONARY',
            'id': '18888881_508',
            'isBusiness': False,
            'isCustom': False,
            'isDeleted': False,
            'isEditable': False,
            'isIgnored': False,
            'isUnassignable': False,
            'isUnbudgetable': False,
            'isUntrendable': False,
            'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                         'link': [{'href': '/v1/categories/18888881_508',
                                   'otherAttributes': {},
                                   'rel': 'self'}]},
            'name': 'Sports',
            'parentId': '18888881_5',
            'type': 'Category'},
 'State Tax': {'categoryType': 'EXPENSE',
               'depth': 2,
               'discretionaryType': 'NON_DISCRETIONARY',
               'id': '18888881_1902',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                            'link': [{'href': '/v1/categories/18888881_1902',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'State Tax',
               'parentId': '18888881_19',
               'type': 'Category'},
 'Student Loan': {'categoryType': 'EXPENSE',
                  'depth': 2,
                  'discretionaryType': 'NON_DISCRETIONARY',
                  'id': '18888881_1002',
                  'isBusiness': False,
                  'isCustom': False,
                  'isDeleted': False,
                  'isEditable': False,
                  'isIgnored': False,
                  'isUnassignable': False,
                  'isUnbudgetable': False,
                  'isUntrendable': False,
                  'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                               'link': [{'href': '/v1/categories/18888881_1002',
                                         'otherAttributes': {},
                                         'rel': 'self'}]},
                  'name': 'Student Loan',
                  'parentId': '18888881_10',
                  'type': 'Category'},
 'Taxes': {'categoryType': 'EXPENSE',
           'depth': 1,
           'discretionaryType': 'NON_DISCRETIONARY',
           'id': '18888881_19',
           'isBusiness': False,
           'isCustom': False,
           'isDeleted': False,
           'isEditable': False,
           'isIgnored': False,
           'isUnassignable': False,
           'isUnbudgetable': False,
           'isUntrendable': False,
           'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                        'link': [{'href': '/v1/categories/18888881_19',
                                  'otherAttributes': {},
                                  'rel': 'self'}]},
           'name': 'Taxes',
           'type': 'Category'},
 'Television': {'categoryType': 'EXPENSE',
                'depth': 2,
                'discretionaryType': 'DISCRETIONARY',
                'id': '18888881_1301',
                'isBusiness': False,
                'isCustom': False,
                'isDeleted': False,
                'isEditable': False,
                'isIgnored': False,
                'isUnassignable': False,
                'isUnbudgetable': False,
                'isUntrendable': False,
                'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                             'link': [{'href': '/v1/categories/18888881_1301',
                                       'otherAttributes': {},
                                       'rel': 'self'}]},
                'name': 'Television',
                'parentId': '18888881_13',
                'type': 'Category'},
 'Toys': {'categoryType': 'EXPENSE',
          'depth': 2,
          'discretionaryType': 'DISCRETIONARY',
          'id': '18888881_606',
          'isBusiness': False,
          'isCustom': False,
          'isDeleted': False,
          'isEditable': False,
          'isIgnored': False,
          'isUnassignable': False,
          'isUnbudgetable': False,
          'isUntrendable': False,
          'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                       'link': [{'href': '/v1/categories/18888881_606',
                                 'otherAttributes': {},
                                 'rel': 'self'}]},
          'name': 'Toys',
          'parentId': '18888881_6',
          'type': 'Category'},
 'Trade Commissions': {'categoryType': 'EXPENSE',
                       'depth': 2,
                       'discretionaryType': 'NON_DISCRETIONARY',
                       'id': '18888881_1607',
                       'isBusiness': False,
                       'isCustom': False,
                       'isDeleted': False,
                       'isEditable': False,
                       'isIgnored': False,
                       'isUnassignable': False,
                       'isUnbudgetable': False,
                       'isUntrendable': False,
                       'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                                    'link': [{'href': '/v1/categories/18888881_1607',
                                              'otherAttributes': {},
                                              'rel': 'self'}]},
                       'name': 'Trade Commissions',
                       'parentId': '18888881_16',
                       'type': 'Category'},
 'Transfer': {'categoryType': 'NO_CATEGORY',
              'depth': 1,
              'discretionaryType': 'NONE',
              'id': '18888881_21',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': True,
              'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                           'link': [{'href': '/v1/categories/18888881_21',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Transfer',
              'type': 'Category'},
 'Transfer for Cash Spending': {'categoryType': 'NO_CATEGORY',
                                'depth': 2,
                                'discretionaryType': 'NONE',
                                'id': '18888881_2102',
                                'isBusiness': False,
                                'isCustom': False,
                                'isDeleted': False,
                                'isEditable': False,
                                'isIgnored': False,
                                'isUnassignable': False,
                                'isUnbudgetable': False,
                                'isUntrendable': True,
                                'metaData': {'lastUpdatedDate': '2021-08-20T23:11:25Z',
                                             'link': [{'href': '/v1/categories/18888881_2102',
                                                       'otherAttributes': {},
                                                       'rel': 'self'}]},
                                'name': 'Transfer for Cash Spending',
                                'parentId': '18888881_21',
                                'type': 'Category'},
 'Travel': {'categoryType': 'EXPENSE',
            'depth': 1,
            'discretionaryType': 'DISCRETIONARY',
            'id': '18888881_15',
            'isBusiness': False,
            'isCustom': False,
            'isDeleted': False,
            'isEditable': False,
            'isIgnored': False,
            'isUnassignable': False,
            'isUnbudgetable': False,
            'isUntrendable': False,
            'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                         'link': [{'href': '/v1/categories/18888881_15',
                                   'otherAttributes': {},
                                   'rel': 'self'}]},
            'name': 'Travel',
            'type': 'Category'},
 'Tuition': {'categoryType': 'EXPENSE',
             'depth': 2,
             'discretionaryType': 'NON_DISCRETIONARY',
             'id': '18888881_1001',
             'isBusiness': False,
             'isCustom': False,
             'isDeleted': False,
             'isEditable': False,
             'isIgnored': False,
             'isUnassignable': False,
             'isUnbudgetable': False,
             'isUntrendable': False,
             'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                          'link': [{'href': '/v1/categories/18888881_1001',
                                    'otherAttributes': {},
                                    'rel': 'self'}]},
             'name': 'Tuition',
             'parentId': '18888881_10',
             'type': 'Category'},
 'Uncategorized': {'categoryType': 'EXPENSE',
                   'depth': 1,
                   'discretionaryType': 'DISCRETIONARY',
                   'id': '18888881_20',
                   'isBusiness': False,
                   'isCustom': False,
                   'isDeleted': False,
                   'isEditable': False,
                   'isIgnored': False,
                   'isUnassignable': False,
                   'isUnbudgetable': False,
                   'isUntrendable': False,
                   'metaData': {'lastUpdatedDate': '2021-02-09T06:59:51Z',
                                'link': [{'href': '/v1/categories/18888881_20',
                                          'otherAttributes': {},
                                          'rel': 'self'}]},
                   'name': 'Uncategorized',
                   'type': 'Category'},
 'Utilities': {'categoryType': 'EXPENSE',
               'depth': 2,
               'discretionaryType': 'NON_DISCRETIONARY',
               'id': '18888881_1306',
               'isBusiness': False,
               'isCustom': False,
               'isDeleted': False,
               'isEditable': False,
               'isIgnored': False,
               'isUnassignable': False,
               'isUnbudgetable': False,
               'isUntrendable': False,
               'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                            'link': [{'href': '/v1/categories/18888881_1306',
                                      'otherAttributes': {},
                                      'rel': 'self'}]},
               'name': 'Utilities',
               'parentId': '18888881_13',
               'type': 'Category'},
 'Vacation': {'categoryType': 'EXPENSE',
              'depth': 2,
              'discretionaryType': 'DISCRETIONARY',
              'id': '18888881_1504',
              'isBusiness': False,
              'isCustom': False,
              'isDeleted': False,
              'isEditable': False,
              'isIgnored': False,
              'isUnassignable': False,
              'isUnbudgetable': False,
              'isUntrendable': False,
              'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                           'link': [{'href': '/v1/categories/18888881_1504',
                                     'otherAttributes': {},
                                     'rel': 'self'}]},
              'name': 'Vacation',
              'parentId': '18888881_15',
              'type': 'Category'},
 'Veterinary': {'categoryType': 'EXPENSE',
                'depth': 2,
                'discretionaryType': 'NON_DISCRETIONARY',
                'id': '18888881_903',
                'isBusiness': False,
                'isCustom': False,
                'isDeleted': False,
                'isEditable': False,
                'isIgnored': False,
                'isUnassignable': False,
                'isUnbudgetable': False,
                'isUntrendable': False,
                'metaData': {'lastUpdatedDate': '2020-11-18T07:31:48Z',
                             'link': [{'href': '/v1/categories/18888881_903',
                                       'otherAttributes': {},
                                       'rel': 'self'}]},
                'name': 'Veterinary',
                'parentId': '18888881_9',
                'type': 'Category'},
 'Withdrawal': {'categoryType': 'NO_CATEGORY',
                'depth': 2,
                'discretionaryType': 'NONE',
                'id': '18888881_5002',
                'isBusiness': False,
                'isCustom': False,
                'isDeleted': False,
                'isEditable': False,
                'isIgnored': False,
                'isUnassignable': True,
                'isUnbudgetable': True,
                'isUntrendable': True,
                'metaData': {'lastUpdatedDate': '2008-01-01T08:00:00Z',
                             'link': [{'href': '/v1/categories/18888881_5002',
                                       'otherAttributes': {},
                                       'rel': 'self'}]},
                'name': 'Withdrawal',
                'parentId': '18888881_50',
                'type': 'Category'}}
